# Distributions-package

Author: Anastasia Syntychaki

Email: asyntychaki@gmail.com

## About:
This is an OOP-based package named <i>distributions-asyn</i> for calculating and visualizing Gaussian and Binomial distributions of numerical data.

## Installation:
The <i>distributions-asyn</i> package requires Python 3.x versions. It has the following dependencies:

* Matplotlib
* Math

It is available at PyPI and can be installed using:
>> pip install distributions-asyn


## File Descriptions:
* <b>distributions-asyn/Generaldistribution.py:</b> A generic distribution class that calculates and visualizes a probability distribution.
* <b>distributions-asyn/Gaussiandistribution.py:</b> A Gaussian distribution that inherits from the Generaldistribution. It calculates and visualizes a Gaussian distribution.
* <b>distributions-asyn/Binomialdistribution.py:</b> A Binomial distribution that inherits from the Generaldistribution. It calculates and visualizes a Binomial distribution.
* <b>distributions-asyn/\_\_init\_\_.py:</b> The package initialization file.
* <b>distributions-asyn/setup.cfg:</b> README.md metadata.
* <b>distributions-asyn/license.txt:</b> Copyright information.
* <b>setup.py:</b> Setup file with package metadata.
